@@ -47,10 +47,11 @@ public:
     SwitchItem::Ptr m_hotspotSwitch;
     SwitchItem::Ptr m_wifiSwitch;
 
-    QuickAccessSection::Ptr m_quickAccessSection;
-    WifiSection::Ptr m_wifiSection;
-    WwanSection::Ptr m_wwanSection;
-    VpnSection::Ptr m_vpnSection;
+    QuickAccessSection::SPtr m_quickAccessSection;
+    EthernetSection::SPtr m_ethernetSection;
+    WifiSection::SPtr m_wifiSection;
+    WwanSection::SPtr m_wwanSection;
+    VpnSection::SPtr m_vpnSection;
 
     MenuExporter::UPtr m_desktopMenuExporter;
     MenuExporter::UPtr m_desktopGreeterMenuExporter;
@@ -156,6 +157,7 @@ MenuBuilder::MenuBuilder(nmofono::Manager::Ptr manager, Factory& factory) :
 
     d->m_quickAccessSection = factory.newQuickAccessSection(d->m_flightModeSwitch);
     d->m_wwanSection = factory.newWwanSection(d->m_mobileDataSwitch, d->m_hotspotSwitch);
+    d->m_ethernetSection = factory.newEthernetSection();
     d->m_wifiSection = factory.newWiFiSection(d->m_wifiSwitch);
     d->m_vpnSection = factory.newVpnSection();
 
@@ -169,6 +171,11 @@ MenuBuilder::MenuBuilder(nmofono::Manager::Ptr manager, Factory& factory) :
     d->m_phoneMenu->addSection(d->m_wwanSection);
     d->m_phoneGreeterMenu->addSection(d->m_wwanSection);
 
+    d->m_desktopMenu->addSection(d->m_ethernetSection);
+    d->m_desktopGreeterMenu->addSection(d->m_ethernetSection);
+    d->m_phoneMenu->addSection(d->m_ethernetSection);
+    d->m_phoneGreeterMenu->addSection(d->m_ethernetSection);
+
     d->m_desktopMenu->addSection(d->m_wifiSection);
     d->m_desktopGreeterMenu->addSection(d->m_wifiSection);
     d->m_phoneMenu->addSection(d->m_wifiSection);
@@ -179,20 +186,6 @@ MenuBuilder::MenuBuilder(nmofono::Manager::Ptr manager, Factory& factory) :
     d->m_phoneMenu->addSection(d->m_vpnSection);
     d->m_phoneGreeterMenu->addSection(d->m_vpnSection);
 
-    d->m_desktopMenuExporter = factory.newMenuExporter("/com/canonical/indicator/network/desktop", d->m_desktopMenu->menu());
-    d->m_desktopGreeterMenuExporter = factory.newMenuExporter("/com/canonical/indicator/network/desktop_greeter", d->m_desktopGreeterMenu->menu());
-    d->m_desktopWifiSettingsMenuExporter = factory.newMenuExporter("/com/canonical/indicator/network/desktop_wifi_settings", d->m_wifiSection->settingsModel());
-
-    d->m_tabletpMenuExporter = factory.newMenuExporter("/com/canonical/indicator/network/tablet", d->m_tabletMenu->menu());
-    d->m_tabletGreeterMenuExporter = factory.newMenuExporter("/com/canonical/indicator/network/tablet_greeter", d->m_tabletGreeterMenu->menu());
-    d->m_tabletWifiSettingsMenuExporter = factory.newMenuExporter("/com/canonical/indicator/network/tablet_wifi_settings", d->m_wifiSection->settingsModel());
-
-    d->m_phoneMenuExporter = factory.newMenuExporter("/com/canonical/indicator/network/phone", d->m_phoneMenu->menu());
-    d->m_phoneGreeterMenuExporter = factory.newMenuExporter("/com/canonical/indicator/network/phone_greeter", d->m_phoneGreeterMenu->menu());
-    d->m_phoneWifiSettingsMenuExporter = factory.newMenuExporter("/com/canonical/indicator/network/phone_wifi_settings", d->m_wifiSection->settingsModel());
-
-    d->m_ubiquityMenuExporter = factory.newMenuExporter("/com/canonical/indicator/network/ubiquity", d->m_ubiquityMenu->menu());
-
     // we have a single actiongroup for all the menus.
     d->m_actionGroupMerger = factory.newActionGroupMerger();
     d->m_actionGroupMerger->add(d->m_flightModeSwitch->actionGroup());
@@ -205,6 +198,20 @@ MenuBuilder::MenuBuilder(nmofono::Manager::Ptr manager, Factory& factory) :
     d->m_actionGroupExporter = factory.newActionGroupExporter(d->m_actionGroupMerger->actionGroup(),
                                                         "/com/canonical/indicator/network");
 
+    d->m_desktopMenuExporter = factory.newMenuExporter("/com/canonical/indicator/network/desktop", d->m_desktopMenu->menu());
+	d->m_desktopGreeterMenuExporter = factory.newMenuExporter("/com/canonical/indicator/network/desktop_greeter", d->m_desktopGreeterMenu->menu());
+	d->m_desktopWifiSettingsMenuExporter = factory.newMenuExporter("/com/canonical/indicator/network/desktop_wifi_settings", d->m_wifiSection->settingsModel());
+
+	d->m_tabletpMenuExporter = factory.newMenuExporter("/com/canonical/indicator/network/tablet", d->m_tabletMenu->menu());
+	d->m_tabletGreeterMenuExporter = factory.newMenuExporter("/com/canonical/indicator/network/tablet_greeter", d->m_tabletGreeterMenu->menu());
+	d->m_tabletWifiSettingsMenuExporter = factory.newMenuExporter("/com/canonical/indicator/network/tablet_wifi_settings", d->m_wifiSection->settingsModel());
+
+	d->m_phoneMenuExporter = factory.newMenuExporter("/com/canonical/indicator/network/phone", d->m_phoneMenu->menu());
+	d->m_phoneGreeterMenuExporter = factory.newMenuExporter("/com/canonical/indicator/network/phone_greeter", d->m_phoneGreeterMenu->menu());
+	d->m_phoneWifiSettingsMenuExporter = factory.newMenuExporter("/com/canonical/indicator/network/phone_wifi_settings", d->m_wifiSection->settingsModel());
+
+	d->m_ubiquityMenuExporter = factory.newMenuExporter("/com/canonical/indicator/network/ubiquity", d->m_ubiquityMenu->menu());
+
     d->m_busName = factory.newBusName("com.canonical.indicator.network",
                                 [](std::string) {
 #ifdef INDICATOR_NETWORK_TRACE_MESSAGES
