@@ -18,10 +18,12 @@
 
 #pragma once
 
+#include <QDBusObjectPath>
 #include <QObject>
 #include <QSet>
 
 #include <nmofono/connection/active-connection.h>
+#include <dbus-types.h>
 
 namespace nmofono
 {
@@ -41,8 +43,14 @@ public:
 
     QSet<ActiveConnection::SPtr> connections() const;
 
+    ActiveConnection::SPtr connection(const QDBusObjectPath& path) const;
+
     bool deactivate(ActiveConnection::SPtr activeConnection);
 
+    ActiveConnection::SPtr activate(const QDBusObjectPath& connection, const QDBusObjectPath& device = QDBusObjectPath("/"), const QDBusObjectPath& specificObject = QDBusObjectPath("/"));
+
+    ActiveConnection::SPtr addAndActivate(const QVariantDictMap &connection, const QDBusObjectPath &device, const QDBusObjectPath &specificObject);
+
 Q_SIGNALS:
     void connectionsChanged(const QSet<ActiveConnection::SPtr>& connections);
 
