@@ -40,6 +40,17 @@ using namespace std;
 namespace nmofono
 {
 
+struct ApDevice
+{
+    ApDevice (const QDBusObjectPath& path, const QString& interface) :
+            m_path (path), m_interface (interface)
+    {
+    }
+
+    QDBusObjectPath m_path;
+    QString m_interface;
+};
+
 class HotspotManager::Priv: public QObject
 {
 
@@ -51,7 +62,7 @@ public:
 
     void addConnection()
     {
-        qDebug() << __PRETTY_FUNCTION__ << "Adding new hotspot connection";
+        qDebug() << "Adding new hotspot connection";
         QVariantDictMap connection = createConnectionSettings(m_ssid, m_password,
                                                               m_mode, m_auth);
 
@@ -80,7 +91,7 @@ public:
 
     void updateConnection()
     {
-        qDebug() << __PRETTY_FUNCTION__ << "Updating hotspot connection";
+        qDebug() << "Updating hotspot connection";
         // Get new settings
         QVariantDictMap new_settings = createConnectionSettings(m_ssid,
                                                                 m_password,
@@ -97,18 +108,27 @@ public:
 
     bool activateConnection(const QDBusObjectPath& device)
     {
-        auto reply = m_manager->ActivateConnection(
-                        QDBusObjectPath(m_hotspot->path()), device,
-                        QDBusObjectPath("/"));
-        reply.waitForFinished();
-        if (reply.isError())
+        auto activeConnectionObject = m_activeConnectionManager->activate(QDBusObjectPath(m_hotspot->path()), device);
+        if (!activeConnectionObject)
         {
-            qCritical() << "Could not activate hotspot connection"
-                    << reply.error().message();
+            qCritical() << "Could not activate hotspot connection";
             return false;
         }
 
-        return true;
+        OrgFreedesktopNetworkManagerConnectionActiveInterface activeConnection (
+                    NM_DBUS_SERVICE, activeConnectionObject->path().path (),
+                    m_manager->connection());
+
+        int count = 0;
+        // Wait for connection to activate
+        while (count < 20 && activeConnection.state() != NM_ACTIVE_CONNECTION_STATE_ACTIVATED)
+        {
+            qDebug() << "Waiting for hotspot to connect";
+            QThread::msleep(100);
+            ++count;
+        }
+
+        return (activeConnection.state() == NM_ACTIVE_CONNECTION_STATE_ACTIVATED);
     }
 
     /**
@@ -118,17 +138,21 @@ public:
     {
         if (!m_hotspot)
         {
-            qWarning() << __PRETTY_FUNCTION__ <<  "Could not find a hotspot setup to enable";
+            qWarning() << "Could not find a hotspot setup to enable";
             return;
         }
 
-        qDebug() << __PRETTY_FUNCTION__ << "Activating hotspot on device" << device.path();
-        setEnable(activateConnection(device));
-        // If our connection gets booted, reconnect
-        connect(m_activeConnectionManager.get(),
-                &connection::ActiveConnectionManager::connectionsUpdated, this,
-                &Priv::reactivateConnection,
-                Qt::QueuedConnection);
+        qDebug() << "Activating hotspot on device" << device.path();
+        bool success = activateConnection(device);
+        setEnable(success);
+        if (success)
+        {
+            // If our connection gets booted, reconnect
+            connect(m_activeConnectionManager.get(),
+                    &connection::ActiveConnectionManager::connectionsUpdated, this,
+                    &Priv::reactivateConnection,
+                    Qt::QueuedConnection);
+        }
     }
 
     /**
@@ -271,10 +295,9 @@ public:
         return true;
     }
 
-
-    QDBusObjectPath getApDevice()
+    void findApDevice()
     {
-        QDBusObjectPath result("/");
+        m_device.release();
         QString tetherIface = getTetheringInterface();
 
         auto devices = QList<QDBusObjectPath>(m_manager->GetDevices()).toStdList();
@@ -293,35 +316,37 @@ public:
                 }
             }
 
-            if (device.deviceType() == NM_DEVICE_TYPE_WIFI)
+            if (device.deviceType() != NM_DEVICE_TYPE_WIFI)
             {
-                qDebug() << "Using AP interface " << interface;
-                m_interface = interface;
-                result = *path;
-                break;
+                continue;
             }
-        }
 
-        return result;
+            if (device.state() <= NM_DEVICE_STATE_UNAVAILABLE)
+            {
+                continue;
+            }
+
+            qDebug() << "Using AP interface " << interface;
+            m_device = make_unique<ApDevice>(*path, interface);
+            break;
+        }
     }
 
-    QDBusObjectPath createApDevice()
+    void createApDevice()
     {
         setInterfaceFirmware("/", m_mode);
 
-        QDBusObjectPath result("/");
+        m_device.release();
 
         int count = 0;
         // Wait for AP device to appear
-        while (count < 20 && result.path() == "/")
+        while (count < 20 && !m_device)
         {
             QThread::msleep(100);
-            result = getApDevice();
-            qDebug() << __PRETTY_FUNCTION__ << "Searching for AP device" << result.path();
+            findApDevice();
+            qDebug() << "Searching for AP device";
             ++count;
         }
-
-        return result;
     }
 
     // wpa_supplicant interaction
@@ -343,10 +368,13 @@ public:
         QVariantDictMap connection;
 
         QString s_ssid = QString::fromLatin1(ssid);
-        QString s_uuid = QUuid().createUuid().toString();
-        // Remove {} from the generated uuid.
-        s_uuid.remove(0, 1);
-        s_uuid.remove(s_uuid.size() - 1, 1);
+
+        if (m_uuid.isEmpty()) {
+            m_uuid = QUuid().createUuid().toString();
+            // Remove {} from the generated uuid.
+            m_uuid.remove(0, 1);
+            m_uuid.remove(m_uuid.size() - 1, 1);
+        }
 
         QVariantMap wireless;
 
@@ -362,15 +390,12 @@ public:
         QVariantMap connsettings;
         connsettings[QStringLiteral("autoconnect")] = QVariant(autoConnect);
         connsettings[QStringLiteral("id")] = QVariant(s_ssid);
-        connsettings[QStringLiteral("uuid")] = QVariant(s_uuid);
+        connsettings[QStringLiteral("uuid")] = QVariant(m_uuid);
         connsettings[QStringLiteral("type")] = QVariant(QStringLiteral("802-11-wireless"));
         connection["connection"] = connsettings;
 
         QVariantMap ipv4;
-        ipv4[QStringLiteral("addressess")] = QVariant(QStringList());
-        ipv4[QStringLiteral("dns")] = QVariant(QStringList());
         ipv4[QStringLiteral("method")] = QVariant(QStringLiteral("shared"));
-        ipv4[QStringLiteral("routes")] = QVariant(QStringList());
         connection["ipv4"] = ipv4;
 
         QVariantMap ipv6;
@@ -443,11 +468,13 @@ public:
                 if (wifi_mode == m_mode)
                 {
                     m_hotspot = conn;
+                    m_uuid = connection_settings["connection"]["uuid"].toString();
                     return;
                 }
             }
         }
         m_hotspot.reset();
+        m_uuid = QString();
     }
 
     connection::ActiveConnection::SPtr getActiveConnection()
@@ -513,7 +540,7 @@ public Q_SLOTS:
     {
         if (!m_hotspot)
         {
-            qWarning() << __PRETTY_FUNCTION__ <<  "Could not find a hotspot setup to enable";
+            qWarning() << "Could not find a hotspot setup to enable";
             return;
         }
 
@@ -524,16 +551,16 @@ public Q_SLOTS:
         }
 
 
-        auto device = getApDevice();
+        findApDevice();
 
-        if (device.path() != "/")
+        if (m_device)
         {
-            qDebug() << __PRETTY_FUNCTION__ << "Reactivating hotspot connection on device" << device.path();
-            activateConnection(device);
+            qDebug() << "Reactivating hotspot connection on device" << m_device->m_path.path();
+            activateConnection(m_device->m_path);
         }
         else
         {
-            qWarning() << __PRETTY_FUNCTION__ << "Could not get device when reactivating hotspot connection";
+            qWarning() << "Could not get device when reactivating hotspot connection";
         }
     }
 
@@ -546,7 +573,8 @@ public:
     bool m_stored = false;
     QString m_password;
     QByteArray m_ssid = "Ubuntu";
-    QString m_interface;
+
+    unique_ptr<ApDevice> m_device;
 
     QPowerd::UPtr m_powerd;
     QPowerd::RequestSPtr m_wakelock;
@@ -571,6 +599,8 @@ public:
 
     shared_ptr<OrgFreedesktopNetworkManagerSettingsConnectionInterface> m_hotspot;
 
+    QString m_uuid;
+
     connection::ActiveConnectionManager::SPtr m_activeConnectionManager;
 };
 
@@ -613,7 +643,7 @@ void HotspotManager::setEnabled(bool value)
         // If the SSID is empty, we report an error.
         if (d->m_ssid.isEmpty())
         {
-            qWarning() << __PRETTY_FUNCTION__ << "  SSID was empty";
+            qWarning() << "  SSID was empty";
             Q_EMIT reportError(1);
             d->setEnable(false);
             return;
@@ -622,11 +652,11 @@ void HotspotManager::setEnabled(bool value)
         d->setDisconnectWifi(true);
 
         // We use Hybris to load the new device firmware
-        auto device = d->createApDevice();
+        d->createApDevice();
 
-        if (device.path() == "/")
+        if (!d->m_device)
         {
-            qWarning() << __PRETTY_FUNCTION__ << "Failed to create AP device";
+            qWarning() << "Failed to create AP device";
             Q_EMIT reportError(1);
             d->setDisconnectWifi(false);
             return;
@@ -640,7 +670,7 @@ void HotspotManager::setEnabled(bool value)
         {
             d->addConnection();
         }
-        d->enable(device);
+        d->enable(d->m_device->m_path);
     }
     else
     {
@@ -694,8 +724,8 @@ QString HotspotManager::auth() const {
 
 QString HotspotManager::interface() const
 {
-    if (enabled())
-        return d->m_interface;
+    if (enabled() && d->m_device)
+        return d->m_device->m_interface;
     else
         return QString();
 }
