@@ -125,6 +125,8 @@ public:
 
     bool m_shouldTriggerUnlock = false;
 
+    QString m_nmPath;
+
     Private(Modem& parent, shared_ptr<QOfonoModem> ofonoModem)
         : p(parent), m_ofonoModem{ofonoModem}
     {
@@ -731,6 +733,19 @@ Modem::ofonoPath() const
     return d->m_ofonoModem->modemPath();
 }
 
+QString
+Modem::nmPath() const
+{
+    return d->m_nmPath;
+}
+
+void
+Modem::setNmPath(const QString& path)
+{
+    d->m_nmPath = path;
+}
+
+
 WwanLink::WwanType
 Modem::wwanType() const
 {
